/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "filelistview.h"
#include "fileviewitem.h"
#include <kfileitem.h>
#include <kpopupmenu.h>
#include <klocale.h>
#include <kglobal.h>
#include <kiconloader.h>
#include "sweepfileinfo.h"

FileListView::FileListView(QWidget *parent, FileListView *prev): QListView(parent), prevview(prev)
{
	if (prevview)
		prevview->nextview = this;
	nextview = NULL;

	diricon = new QPixmap(KGlobal::iconLoader()->loadIcon("folder", KIcon::Small));
	menu = new KPopupMenu(this);
	menu->insertItem(*diricon, i18n("Open directory"), this, SLOT(openDirSelected()));

	connect(this, SIGNAL(contextMenuRequested(QListViewItem *, const QPoint&, int)), this, SLOT(showContextMenu(QListViewItem *, const QPoint&, int)));
}

FileListView::~ FileListView()
{
	if (prevview)
		prevview->nextview = nextview;
	if (nextview)
		nextview->prevview = prevview;
	delete diricon;
}

void FileListView::setupColumns()
{
        addColumn("Name");
        addColumn("Directory");
        addColumn("Size");
        addColumn("Date");
        addColumn("Permissions");
        addColumn("Owner");
        addColumn("Group");
}

void FileListView::stateChanged(SweepFileInfo *f, bool state)
{
	//
	// propagate change to other views
	for (FileListView *v = prevview; v; v = v->prevview)
	{
		QListViewItemIterator it(v);
		while (it.current())
		{
			FileViewItem *item = dynamic_cast<FileViewItem *>(*it);
			if (item && item->fileItem() == f)
				item->setOn(state);
			++it;
    		}
	}
	for (FileListView *v = nextview; v; v = v->nextview)
	{
		QListViewItemIterator it(v);
		while (it.current())
		{
			FileViewItem *item = dynamic_cast<FileViewItem *>(*it);
			if (item && item->fileItem() == f)
				item->setOn(state);
			++it;
    		}
	}
}

FileViewItem* FileListView::find(SweepFileInfo *f)
{
	QListViewItemIterator it(this);
	while (it.current())
	{
		FileViewItem *item = dynamic_cast<FileViewItem *>(*it);
		if (item && item->fileItem() == f)
			return item;
		++it;
	}
	return NULL;
}

KPopupMenu* FileListView::contextMenu() const
{
	return menu;
}
		
void FileListView::showContextMenu(QListViewItem *item, const QPoint &point, int col)
{
	if (FileViewItem *f = dynamic_cast<FileViewItem*>(item))
	{
		menu->popup(point);
	}
}

void FileListView::openDirSelected()
{
	if (FileViewItem *f = dynamic_cast<FileViewItem*>(selectedItem()))
		emit openDirectory(f->fileItem()->url().directory());
}

#include "filelistview.moc"
