/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "fileviewitem.h"
#include "filelistview.h"
#include "sweepfileinfo.h"
#include <kglobal.h>
#include <klocale.h>

FileViewItem::FileViewItem(FileListView *parent, SweepFileInfo *f): QCheckListItem(parent, QString::null, CheckBox), finfo(f)
{
	setColumns();
}

FileViewItem::FileViewItem(FileViewItem *parent, SweepFileInfo *f): QCheckListItem(parent, QString::null, CheckBox), finfo(f)
{
	setColumns();
}

FileViewItem::~FileViewItem()
{
}

void FileViewItem::setColumns()
{
	if (finfo)
	{
		int i = 0;
		QString target = finfo->getTarget();
		setPixmap(i, finfo->pixmap(16));
		setText(i++, finfo->name());
		setText(i++, finfo->url().directory());
		if (!target.isNull())
			setText(i++, target);
		setText(i++, KGlobal::locale()->formatNumber(finfo->size(), 0));
		setText(i++, finfo->timeString());
		setText(i++, finfo->permissionsString());
		setText(i++, finfo->user());
		setText(i++, finfo->group());
		setOn(finfo->isMarkedForRemoval());
	}
}

SweepFileInfo* FileViewItem::fileItem() const
{
	return finfo;
}

void FileViewItem::stateChange(bool f)
{
	if (finfo && finfo->isMarkedForRemoval() != f)
	{
		finfo->markForRemoval(f);
		if (FileListView *list = dynamic_cast<FileListView*>(listView()))
			list->stateChanged(finfo, f);
	}
}

